@@ -1,6 +1,6 @@
 # This script generates the PyQt configuration and generates the Makefiles.
 #
-# Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt.
 # 
@@ -33,10 +33,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040900
-pyqt_version_str = "4.9"
+pyqt_version = 0x040903
+pyqt_version_str = "4.9.3"
 
-sip_min_version = 0x040d01
+sip_min_version = 0x040d03
 
 qt_version = 0
 qt_edition = ""
@@ -51,6 +51,10 @@ qt_xfeatures = None
 qt_shared = ""
 qt_framework = 0
 
+# This default value will be used by the code that bootstraps the Qt
+# configuration.
+qt_macx_spec = 'macx-g++'
+
 qt_sip_flags = []
 
 pyqt_modules = []
@@ -175,7 +179,7 @@ def create_optparser():
             "comments of generated code [default: include timestamps]")
 
     if sys.platform != 'win32':
-        if sys.platform in ('linux2', 'linux3', 'darwin'):
+        if sys.platform.startswith('linux') or sys.platform == 'darwin':
             pip_default = True
             pip_default_str = "enabled"
         else:
@@ -335,7 +339,8 @@ class ConfigurePyQt4:
             0x040701: "Qt_4_7_0",
             0x040702: "Qt_4_7_1",
             0x040800: "Qt_4_7_2",
-            0x050000: "Qt_4_8_0"
+            0x050000: "Qt_4_8_0",
+            0x060000: "Qt_5_0_0"
         }
 
     def check_modules(self):
@@ -346,41 +351,39 @@ class ConfigurePyQt4:
 
         if opts.mwg_ssl_dir:
             ass_lib_dirs = [os.path.join(opts.mwg_ssl_dir, "lib")]
-            ass_libs = ["ssleay32", "libeay32"]
+            ass_libs = ["ssleay32", "libeay32", "QtCore"]
         else:
             ass_lib_dirs = None
-            ass_libs = None
+            ass_libs = ["QtCore"]
 
         # Note that the order in which we check is important for the
         # consolidated module - a module's dependencies must be checked first.
         pyqt_modules.append("QtCore")
 
         check_module("QtGui", "qwidget.h", "new QWidget()")
-        check_module("QtHelp", "qhelpengine.h", "new QHelpEngine(\"foo\")")
-        check_module("QtMultimedia", "QAudioDeviceInfo",
+        if qt_version < 0x050000: check_module("QtHelp", "qhelpengine.h", "new QHelpEngine(\"foo\")",
+                extra_libs=["QtCore"])
+        if qt_version < 0x050000: check_module("QtMultimedia", "QAudioDeviceInfo",
                 "new QAudioDeviceInfo()")
-        check_module("QtNetwork", "qhostaddress.h", "new QHostAddress()")
-
-        if sys.platform != 'win32':
-            check_module("QtDBus", "qdbusconnection.h",
-                    "QDBusConnection::systemBus()")
-
-        check_module("QtDeclarative", "qdeclarativeview.h",
+        if qt_version < 0x050000: check_module("QtNetwork", "qhostaddress.h", "new QHostAddress()")
+        if qt_version < 0x050000: check_module("QtDBus", "qdbusconnection.h",
+                "QDBusConnection::systemBus()")
+        if qt_version < 0x050000: check_module("QtDeclarative", "qdeclarativeview.h",
                 "new QDeclarativeView()")
-        check_module("QtOpenGL", "qgl.h", "new QGLWidget()")
-        check_module("QtScript", "qscriptengine.h", "new QScriptEngine()")
-        check_module("QtScriptTools", "qscriptenginedebugger.h",
+        if qt_version < 0x050000: check_module("QtOpenGL", "qgl.h", "new QGLWidget()")
+        if qt_version < 0x050000: check_module("QtScript", "qscriptengine.h", "new QScriptEngine()")
+        if qt_version < 0x050000: check_module("QtScriptTools", "qscriptenginedebugger.h",
                 "new QScriptEngineDebugger()")
-        check_module("QtSql", "qsqldatabase.h", "new QSqlDatabase()",
+        if qt_version < 0x050000: check_module("QtSql", "qsqldatabase.h", "new QSqlDatabase()",
                 extra_libs=sql_libs)
-        check_module("QtSvg", "qsvgwidget.h", "new QSvgWidget()")
-        check_module("QtTest", "QtTest", "QTest::qSleep(0)")
-        check_module("QtWebKit", "qwebpage.h", "new QWebPage()")
-        check_module("QtXml", "qdom.h", "new QDomDocument()")
-        check_module("QtXmlPatterns", "qxmlname.h", "new QXmlName()")
-        check_module("phonon", "phonon/videowidget.h",
+        if qt_version < 0x050000: check_module("QtSvg", "qsvgwidget.h", "new QSvgWidget()")
+        if qt_version < 0x050000: check_module("QtTest", "QtTest", "QTest::qSleep(0)")
+        if qt_version < 0x050000: check_module("QtWebKit", "qwebpage.h", "new QWebPage()")
+        if qt_version < 0x050000: check_module("QtXml", "qdom.h", "new QDomDocument()")
+        if qt_version < 0x050000: check_module("QtXmlPatterns", "qxmlname.h", "new QXmlName()")
+        if qt_version < 0x050000: check_module("phonon", "phonon/videowidget.h",
                 "new Phonon::VideoWidget()")
-        check_module("QtAssistant", "qassistantclient.h",
+        if qt_version < 0x050000: check_module("QtAssistant", "qassistantclient.h",
                 "new QAssistantClient(\"foo\")", extra_lib_dirs=ass_lib_dirs,
                 extra_libs=ass_libs)
 
@@ -389,10 +392,10 @@ class ConfigurePyQt4:
         elif sipcfg.universal:
             sipconfig.inform("QtDesigner module disabled with universal binaries.")
         else:
-            check_module("QtDesigner", "QExtensionFactory",
+            if qt_version < 0x050000: check_module("QtDesigner", "QExtensionFactory",
                     "new QExtensionFactory()")
 
-        check_module("QAxContainer", "qaxobject.h", "new QAxObject()",
+        if qt_version < 0x050000: check_module("QAxContainer", "qaxobject.h", "new QAxObject()",
                 extra_libs=["QAxContainer"])
 
         if os.path.isdir(os.path.join(src_dir, "dbus")):
@@ -966,17 +969,25 @@ include(%s)
                 from distutils.sysconfig import get_config_vars
                 ducfg = get_config_vars()
 
+                config_args = ducfg.get("CONFIG_ARGS", "")
+
                 if sys.platform == "darwin":
-                    # We need to work out how to specify the right framework
-                    # version.
-                    link = "-framework Python"
-                elif "--enable-shared" in ducfg.get("CONFIG_ARGS", ""):
+                    dynamic_pylib = "--enable-framework" in config_args
+
+                    # It's probably a Python bug that the library name doesn't
+                    # include the ABI information.
+                    abi = ""
+                else:
+                    dynamic_pylib = "--enable-shared" in config_args
+
+                if dynamic_pylib:
                     if glob.glob("%s/lib/libpython%d.%d*" % (ducfg["exec_prefix"], py_major, py_minor)):
                         lib_dir_flag = quote("-L%s/lib" % ducfg["exec_prefix"])
                     elif glob.glob("%s/libpython%d.%d*" % (ducfg["LIBDIR"], py_major, py_minor)):
                         lib_dir_flag = quote("-L%s" % ducfg["LIBDIR"])
                     else:
                         sipconfig.inform("Qt Designer plugin disabled because Python library couldn't be found")
+                        lib_dir_flag = ''
                         opts.designer_plugin = False
 
                     link = "%s -lpython%d.%d%s" % (lib_dir_flag, py_major, py_minor, abi)
@@ -1377,8 +1388,10 @@ def check_dbus():
         sipconfig.inform("DBus v1 does not seem to be installed.")
         return
 
-    # Using str() means it will work with both Python v2 and v3.
-    for f in str(iflags).split():
+    if sys.hexversion >= 0x03000000:
+        iflags = iflags.decode()
+
+    for f in iflags.split():
         if f.startswith("-I"):
             dbusincdirs.append(f[2:])
         elif f.startswith("-L"):
@@ -1851,15 +1864,25 @@ def get_build_macros(overrides):
 
     overrides is a list of macros overrides from the user.
     """
+    global qt_macx_spec
+
     # Get the name of the qmake configuration file to take the macros from.
     if "QMAKESPEC" in list(os.environ.keys()):
         fname = os.environ["QMAKESPEC"]
 
         if not os.path.dirname(fname):
+            qt_macx_spec = fname
             fname = os.path.join(qt_datadir, "mkspecs", fname)
     elif sys.platform == "darwin":
         # The Qt Mac binary installer defaults to xcode which we don't want.
-        fname = os.path.join(qt_datadir, "mkspecs", "macx-g++")
+        # Use Qt5's macx-clang if it is available, otherwise fall back to
+        # macx-g++.
+        fname = os.path.join(qt_datadir, "mkspecs", "macx-clang")
+        if os.path.isdir(fname):
+            qt_macx_spec = "macx-clang"
+        else:
+            fname = os.path.join(qt_datadir, "mkspecs", "macx-g++")
+            qt_macx_spec = "macx-g++"
     else:
         fname = os.path.join(qt_datadir, "mkspecs", "default")
 
@@ -1880,7 +1903,20 @@ def get_build_macros(overrides):
         "QT_INSTALL_LIBS":      qt_libdir
     }
 
-    return sipconfig.parse_build_macros(fname, names, overrides, properties)
+    macros = sipconfig.parse_build_macros(fname, names, overrides, properties)
+
+    if macros is None:
+        return None
+
+    # Make sure we have an entry for MOC (which Qt v5 doesn't provide).
+    if macros.get("MOC", "") == "":
+        default_moc = os.path.join(qt_bindir, "moc")
+        if sys.platform == 'win32':
+            default_moc += ".exe"
+
+        macros["MOC"] = default_moc
+
+    return macros
 
 
 def check_qt_installation(macros):
@@ -1929,7 +1965,7 @@ def fix_qmake_args(args=""):
     """
     if sys.platform == "darwin":
         # The Qt binary installer has macx-xcode as the default.
-        args = "-spec %s %s" % (sipcfg.platform, args)
+        args = "-spec %s %s" % (qt_macx_spec, args)
 
     return args
 
@@ -1987,6 +2023,11 @@ SOURCES = %s
 #include <QLibraryInfo>
 #include <QTextStream>
 
+// This seems to be missing from the Qt v5 alpha.
+#if !defined(QT_EDITION_OPENSOURCE)
+#define QT_EDITION_OPENSOURCE   8
+#endif
+
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
