@@ -1,6 +1,6 @@
 // This implements the helpers for QObject.
 //
-// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of PyQt.
 // 
@@ -303,11 +303,29 @@ PyObject *qpycore_qobject_staticmetaobject(PyObject *type_obj)
     const QMetaObject *mo;
 
     if (pyqt_wt->metaobject)
+    {
         // It's a sub-type of a wrapped type.
         mo = &pyqt_wt->metaobject->mo;
+    }
     else
+    {
         // It's a wrapped type.
-        mo = reinterpret_cast<const QMetaObject *>(((pyqt4ClassTypeDef *)((sipWrapperType *)pyqt_wt)->type)->qt4_static_metaobject);
+        pyqt4ClassTypeDef *p4ctd = (pyqt4ClassTypeDef *)((sipWrapperType *)pyqt_wt)->type;
+
+        if (!p4ctd)
+        {
+            /*
+             * This is a side effect of a wrapped class not being fully ready
+             * until sip's meta-class's __init__() has run (rather than after
+             * its __new__() method as might be expected).
+             */
+            PyErr_SetString(PyExc_AttributeError,
+                    "staticMetaObject isn't available until the meta-class's __init__ returns");
+            return 0;
+        }
+
+        mo = reinterpret_cast<const QMetaObject *>(p4ctd->qt4_static_metaobject);
+    }
 
     return sipConvertFromType(const_cast<QMetaObject *>(mo), sipType_QMetaObject, 0);
 }
